<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="20"/>
        <source>Boot Repair</source>
        <translation>Opravit zavaděč</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="39"/>
        <source>Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>Oprava zavaděče je nástroj, který lze použít k opětovné instalaci bootloaderu GRUB na ESP (EFI System Partition), MBR (Master Boot Record) nebo kořenový oddíl. Poskytuje možnost rekonstrukce konfiguračního souboru GRUB, zálohování a obnovení MBR nebo PBR (root).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Co si přejete provést?</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Záloha MBR a PBR (pouze pro legacy boot)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Přeinstalovat zavaděč GRUB na ESP, MBR nebo PBR (root)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Opravit konfigurační soubor GRUB-u</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Obnovit MBR nebo PBR ze zálohy (pouze pro legacy boot)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="136"/>
        <location filename="mainwindow.cpp" line="485"/>
        <source>Select Boot Method</source>
        <translation>Vyberte způsob zavedení</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="154"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="157"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="160"/>
        <location filename="mainwindow.ui" line="430"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="182"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root (Partition Boot Record)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="185"/>
        <location filename="mainwindow.cpp" line="488"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="236"/>
        <location filename="mainwindow.cpp" line="487"/>
        <source>Install on:</source>
        <translation>Instalovat na:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="255"/>
        <location filename="mainwindow.cpp" line="486"/>
        <source>Location:</source>
        <translation>Umístnění:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="277"/>
        <location filename="mainwindow.cpp" line="496"/>
        <source>Select root location:</source>
        <translation>Vyberte kořenové umístení:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="290"/>
        <source>EFI System Partition</source>
        <translation>Oddíl systému EFI</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="293"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="420"/>
        <source>About this application</source>
        <translation>O této aplikaci</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="423"/>
        <source>About...</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="472"/>
        <source>Display help </source>
        <translation>Zobrazit nápovědu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="475"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="482"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="523"/>
        <source>Cancel any changes then quit</source>
        <translation>Zrušit všechny změny a ukončit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="526"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="533"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="552"/>
        <source>Apply any changes</source>
        <translation>Uložit všechny změny</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="555"/>
        <location filename="mainwindow.cpp" line="70"/>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB se instaluje na zařízení %1.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="118"/>
        <location filename="mainwindow.cpp" line="203"/>
        <location filename="mainwindow.cpp" line="312"/>
        <location filename="mainwindow.cpp" line="394"/>
        <location filename="mainwindow.cpp" line="419"/>
        <location filename="mainwindow.cpp" line="527"/>
        <location filename="mainwindow.cpp" line="534"/>
        <location filename="mainwindow.cpp" line="597"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="119"/>
        <location filename="mainwindow.cpp" line="204"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Nebylo možné nastavit chroot prostředí.
Prosím zkontrolujte vybrané umístnění.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="179"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>Konfigurační soubor GRUB (grub.cfg) se znovu sestavuje.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="222"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Zálohování MBR nebo PBR ze zařízení %1.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="287"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="288"/>
        <source>You are going to write the content of </source>
        <translation>Chystáte se zapsat obsah</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="288"/>
        <source> to </source>
        <translation>do</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="288"/>
        <source>

Are you sure?</source>
        <translation>

Jste si jistí?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="293"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Obnova MBR/PBR ze zálohy na zařízení %1.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="313"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Nelze najít EFI oddíl (ESP) na systémových discích. Prosím vytvořte ESP a zkuste to znovu.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="348"/>
        <source>Select %1 location:</source>
        <translation>Vybrat umístění %1:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="372"/>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="388"/>
        <source>Success</source>
        <translation>Úspěch!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="389"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit Boot Repair?&lt;/b&gt;</source>
        <translation>Proces byl úspěšně dokončen.&lt;p&gt;&lt;b&gt;Přejete si ukončit program Oprava zavaděče?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="395"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Proces dokončen. Vyskytly se chyby. </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="412"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Zapsat heslo pro odemčení šifrovaného oddílu %1:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="420"/>
        <source>Sorry, could not open %1 LUKS container</source>
        <translation>Omlouváme se, nelze otevřít LUKS kontejner %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="495"/>
        <source>Select GRUB location</source>
        <translation>Vybrat umístění GRUB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="507"/>
        <source>Select Item to Back Up</source>
        <translation>Vyberte položku k záloze</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="514"/>
        <source>Select Item to Restore</source>
        <translation>Vyberte položku k obnově</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="525"/>
        <source>Select backup file name</source>
        <translation>Vyberte název souboru zálohy</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="527"/>
        <location filename="mainwindow.cpp" line="534"/>
        <source>No file was selected.</source>
        <translation>Nebyl vybrán žádný soubor</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="532"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Vyberte soubor MBR nebo PBR zálohy</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="552"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="553"/>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="554"/>
        <source>Simple boot repair program for antiX Linux</source>
        <translation>Jednoduchá oprava zavaděče pro antiX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="556"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Vlastnická práva (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="557"/>
        <source>%1 License</source>
        <translation>Licence %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="571"/>
        <source>%1 Help</source>
        <translation>Nápověda %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="598"/>
        <source>Sorry, could not mount %1 partition</source>
        <translation>Omlouváme se, nelze připojit oddíl %1</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="about.cpp" line="32"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="about.cpp" line="33"/>
        <location filename="about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Protokol změn</translation>
    </message>
    <message>
        <location filename="about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="main.cpp" line="64"/>
        <source>You must run this program as root.</source>
        <translation>Tuto aplikaci musíte spustit jako root.</translation>
    </message>
</context>
</TS>